
/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bseobject.proc"

#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bseobject.h>

#line 25 "bseobject.proc"

/* --- is-a --- */
static void
is_a_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 26 "bseobject.proc"
 {
#line 28 "bseobject.proc"
  *(in_pspecs++)    = bse_param_spec_object ("item", "Item", NULL,
				 BSE_TYPE_OBJECT, SFI_PARAM_DEFAULT);
  *(in_pspecs++)    = sfi_pspec_string ("type_name", "Type Name", NULL,
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = sfi_pspec_bool ("is_a_check", NULL, NULL,
			  FALSE, SFI_PARAM_DEFAULT);
#line 27 "bseobject.proc"
  proc->help = "Check object type";
#line 23 "bseobject.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bseobject.proc"
  proc->license = "GNU Lesser General Public License";
#line 34 "bseobject.proc"
}  }
static BseErrorType
#line 34 "bseobject.proc"
is_a_exec (BseProcedureClass *proc,
        const GValue      *in_values,
        GValue            *out_values)
#line 37 "bseobject.proc"
{
#line 38 "bseobject.proc"
  
  BseObject *object = bse_value_get_object (in_values++);
  gchar *type_name  = sfi_value_get_string (in_values++);
  
#line 42 "bseobject.proc"
  
#line 43 "bseobject.proc"
  if (!type_name)  
    return BSE_ERROR_PROC_PARAM_INVAL;
  
#line 46 "bseobject.proc"
  
  sfi_value_set_bool (out_values++, G_TYPE_CHECK_INSTANCE_TYPE (object, g_type_from_name (type_name)));
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_is_a = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseObject+is-a", "/Methods/BseObject/General/Is A", NULL },
  0, is_a_setup, is_a_exec, 
};
BseExportNode* bse__builtin_init_bseobject_gen_proc_c (void);
BseExportNode* bse__builtin_init_bseobject_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_is_a;
}

/**
 ** Generated data ends here
 **/
